[Libreoffice-commits] online.git: cypress_test/data cypress_test/integration_tests

Tamás Zolnai (via logerrit) logerrit at kemper.freedesktop.org
Wed Apr 22 10:56:20 UTC 2020


 cypress_test/integration_tests/desktop/impress/slide_operations_spec.js |   15 ++++------
 cypress_test/integration_tests/desktop/writer/copy_paste_spec.js        |    4 +-
 cypress_test/integration_tests/desktop/writer/shape_operations_spec.js  |    4 +-
 3 files changed, 10 insertions(+), 13 deletions(-)

New commits:
commit e580e8c7dc5d4d172d7acbb47b2a0b9da72e96e7
Author:     Tamás Zolnai <tamas.zolnai at collabora.com>
AuthorDate: Wed Apr 22 11:34:49 2020 +0200
Commit:     Tamás Zolnai <tamas.zolnai at collabora.com>
CommitDate: Wed Apr 22 12:56:02 2020 +0200

    cypress: desktop: restructure data and test files.
    
    Plus rename one test file: focus.odp -> slide_operations.odp.
    
    Change-Id: I278fc22ec55bcfbd47d2ecda95b759c16b615403
    Reviewed-on: https://gerrit.libreoffice.org/c/online/+/92681
    Tested-by: Jenkins CollaboraOffice <jenkinscollaboraoffice at gmail.com>
    Reviewed-by: Tamás Zolnai <tamas.zolnai at collabora.com>

diff --git a/cypress_test/data/desktop/focus.odp b/cypress_test/data/desktop/impress/slide_operations.odp
similarity index 100%
rename from cypress_test/data/desktop/focus.odp
rename to cypress_test/data/desktop/impress/slide_operations.odp
diff --git a/cypress_test/data/desktop/copy_paste.odt b/cypress_test/data/desktop/writer/copy_paste.odt
similarity index 100%
rename from cypress_test/data/desktop/copy_paste.odt
rename to cypress_test/data/desktop/writer/copy_paste.odt
diff --git a/cypress_test/data/desktop/shape_operations.odt b/cypress_test/data/desktop/writer/shape_operations.odt
similarity index 100%
rename from cypress_test/data/desktop/shape_operations.odt
rename to cypress_test/data/desktop/writer/shape_operations.odt
diff --git a/cypress_test/integration_tests/desktop/copy_paste_spec.js b/cypress_test/integration_tests/desktop/writer/copy_paste_spec.js
similarity index 91%
rename from cypress_test/integration_tests/desktop/copy_paste_spec.js
rename to cypress_test/integration_tests/desktop/writer/copy_paste_spec.js
index 37d6f04dd..130581675 100644
--- a/cypress_test/integration_tests/desktop/copy_paste_spec.js
+++ b/cypress_test/integration_tests/desktop/writer/copy_paste_spec.js
@@ -1,10 +1,10 @@
 /* global describe it cy beforeEach require expect afterEach*/
 
-var helper = require('../common/helper');
+var helper = require('../../common/helper');
 
 describe('Clipboard operations.', function() {
 	beforeEach(function() {
-		helper.loadTestDoc('copy_paste.odt');
+		helper.loadTestDoc('copy_paste.odt', 'writer');
 	});
 
 	afterEach(function() {
diff --git a/cypress_test/integration_tests/desktop/shape_operations_spec.js b/cypress_test/integration_tests/desktop/writer/shape_operations_spec.js
similarity index 89%
rename from cypress_test/integration_tests/desktop/shape_operations_spec.js
rename to cypress_test/integration_tests/desktop/writer/shape_operations_spec.js
index c0a4902c4..764633efd 100644
--- a/cypress_test/integration_tests/desktop/shape_operations_spec.js
+++ b/cypress_test/integration_tests/desktop/writer/shape_operations_spec.js
@@ -1,11 +1,11 @@
 /* global describe it cy require expect afterEach*/
 
-var helper = require('../common/helper');
+var helper = require('../../common/helper');
 
 describe('Shape operations', function() {
 
 	afterEach(function() {
-		helper.afterAll('shape_operations.odt');
+		helper.afterAll('shape_operations.odt', 'writer');
 	});
 
 	it('Insert a simple shape.', function() {


More information about the Libreoffice-commits mailing list
diff --git a/cypress_test/integration_tests/desktop/slide_operations_spec.js b/cypress_test/integration_tests/desktop/impress/slide_operations_spec.js
similarity index 81%
rename from cypress_test/integration_tests/desktop/slide_operations_spec.js
rename to cypress_test/integration_tests/desktop/impress/slide_operations_spec.js
index 3b135d44b..f7031eb3f 100644
--- a/cypress_test/integration_tests/desktop/slide_operations_spec.js
+++ b/cypress_test/integration_tests/desktop/impress/slide_operations_spec.js
@@ -1,11 +1,14 @@
 /* global describe it cy require afterEach*/
 
-var helper = require('../common/helper');
+var helper = require('../../common/helper');
 
 describe('Slide operations', function() {
+	beforeEach(function() {
+		helper.loadTestDoc('slide_operations.odp', 'impress');
+	});
 
 	afterEach(function() {
-		helper.afterAll('focus.odp');
+		helper.afterAll('slide_operations.odp');
 	});
 
 	function assertNumberOfSlides(slides) {
@@ -14,8 +17,6 @@ describe('Slide operations', function() {
 	}
 
 	it('Add slides', function() {
-		helper.loadTestDoc('focus.odp');
-
 		cy.get('#tb_presentation-toolbar_item_insertpage')
 			.should('not.have.class', 'disabled')
 			.click();
@@ -24,8 +25,6 @@ describe('Slide operations', function() {
 	});
 
 	it('Remove slides', function() {
-		helper.loadTestDoc('focus.odp');
-
 		// Add slides
 		cy.get('#tb_presentation-toolbar_item_insertpage')
 			.should('not.have.class', 'disabled')
@@ -48,8 +47,6 @@ describe('Slide operations', function() {
 	});
 
 	it('Duplicate slide', function() {
-		helper.loadTestDoc('focus.odp');
-
 		cy.get('#tb_presentation-toolbar_item_duplicatepage')
 			.should('not.have.class', 'disabled')
 			.click();
@@ -1,11 +1,14 @@
-/* global describe it cy require afterEach*/
+/* global describe it cy require afterEach beforeEach*/
 